Learn R Programming

snreg (version 1.2.0)

snreg-package: snreg: Regression with Skew-Normally Distributed Error Term

Description

Models with skew‑normally distributed and thus asymmetric error terms, implementing the methods developed in Badunenko and Henderson (2023) "Production analysis with asymmetric noise" tools:::Rd_expr_doi("10.1007/s11123-023-00680-5"). The package provides tools to estimate regression models with skew‑normal error terms, allowing both the variance and skewness parameters to be heteroskedastic. It also includes a stochastic frontier framework that accommodates both i.i.d. and heteroskedastic inefficiency terms.

Arguments

Author

Maintainer: Oleg Badunenko Oleg.Badunenko@brunel.ac.uk (ORCID)

Other contributors:

  • John Burkardt (Author of C code for Owen T function) [contributor, copyright holder]

See Also